@@ -34,7 +34,7 @@ the code, but the active DOM objects then need to be discarded.
 
 import xml.dom
 
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 
 class Implementation(object):
 
@@ -521,6 +521,9 @@ class Node(object):
     def toUnicode(self):
         if hasattr(self._node, "toString"):
             return self.impl.get_string(self._node.toString())
+        elif hasattr(self._node, "toHTML"):
+            # Using qtxml implementation since toHTML returns a QString.
+            return qtxmlImplementation().get_string(self._node.toHTML())
         else:
             # NOTE: Verify encodings!
 
